"""This module contains different functions that iterate over sequences such as strings and list.

You can query this documentation using pydoc3 sequenceTools from the terminal"""


# When this module is imported with 
#   from sequenceTools import *
# __all__ keeps track of all the symbols you want the importer to receive:
__all__ = [ "countAllVowels", "countChar", "wordStartEndList", "wordStartEndCount"]

# All functions go below here.



def isVowel(char):
    """Predicate that returns true only when a letter is a vowel.
    >>> isVowel('e')
    True
    >>> isVowel('U')
    True
    >>> isVowel('t')
    False
    >>> isVowel('Z')
    False
    """
    return char.lower() in 'aeiou'


def startsWithVowel(word):
    """Returns true if given word starts with a vowel
    >>>startsWithVowel('hello')
    False
    >>>startsWithVowel('Amelia')
    True"""
    if len(word):
        return isVowel(word[0])
    return False

def countAllVowels(word):
    '''Returns number of vowels in the word.
    >>> countAllVowels('Williams')
    3
    >>> countAllVowels('Eephs')
    2'''
    count = 0 # initialize the counter
    for char in word: # iterate over the word one character at a time
        if isVowel(char):
            count += 1
    return count


def vowelWordList(wordList):
    '''Returns a list of words that start with a vowel from the input list'''
    result = [] # initialize list accumulation variable
    for word in wordList:
        if startsWithVowel(word):
            result.append(word)
    return result


def countChar(char, word):
    '''Counts the number of times a character appears in a word.
    >>> countChar('a', 'Alabama')
    4
    >>> countChar('E', 'Eephs')
    2'''
    count = 0
    for letter in word:
        if char.lower() == letter.lower():
            count += 1
    return count



def wordStartEndCount(wordList):
    '''Takes a list of words and counts the number of words in it that start and end with the same letter.
    >>> wordStartEnd(['Exude', 'Eerie', 'Soup', 'knack', 'snack'])
    3
    >>> wordStartEnd(['Scared', 'Sure', 'Sars', 'Viral', 'viv', 'stills'])
    3
    '''
    count = 0 #initilize counter
    for word in wordList:
        if len(word):  #why do we need this?
            if word[0].lower() == word[-1].lower():  # will this work?
                # debugging print here perhaps
                # print(word)
                count += 1
    return count


def wordStartEndList(wordList):
    '''Takes a list of words and returns a new list of words that start and end with the same letter.
    >>> wordStartEnd(['Exude', 'Eerie', 'Soup', 'knack', 'snack'])
    ['Exude', 'Eerie', 'snack']
    >>> wordStartEnd(['Scared', 'Sure', 'Sars', 'Viral', 'viv', 'stills'])
    ['Sars', 'viv', 'stills']
    '''
    result = [] #initilize list
    for word in wordList:
        if len(word):  #why do we need this?
            if word[0].lower() == word[-1].lower():  # will this work?
                result.append(word)
    return result



if __name__ == "__main__":
    import doctest
    doctest.testmod()  
    #if you want to see output even when tests pass, set optional argument verbose=True
    # that is, doctest.testmod(verbose=True)




